# Data Audit

Functions for explorative data analysis used for e.g. data audits

## Dependencies
- [pandas](https://pandas.pydata.org): 0.22.0 or higher
- [NumPy](http://www.numpy.org): 1.14.0 or higher
- [scikit-learn](http://scikit-learn.org): 0.19.0 or higher
- [seaborn](https://seaborn.pydata.org): 0.8.1 or higher